@@ -44,7 +44,7 @@ class TargetPreModelAnalysis:
         target = self.target
         value_counts = target.value_counts()
         percentages = np.array(value_counts / target.size * 100)
-        fig, ax1 = plt.subplots(figsize=(7, 7), dpi=100)
+        fig, ax1 = plt.subplots(figsize=(8, 8), dpi=100)
         ax2 = ax1.twinx()
 
         # Create a color map that shows the percentage of each target value
@@ -52,7 +52,7 @@ class TargetPreModelAnalysis:
         heatmap = np.array([percentages, ] * len(value_counts))
 
         # Create a bar plot with a heatmap color scheme
-        ax1.barh(value_counts.index, value_counts.values, color=cmap(heatmap))
+        ax1.barh(value_counts.index, value_counts.values)#??
         ax1.set_xlabel('Counts')
         ax1.set_ylabel('Values')
         ax1.invert_yaxis()
